#! /bin/sh
#+
#
# .. program:: pomme_profile.sh
#
# ================
# pomme_profile.sh
# ================
#
# ------------------------
# define POMME environment
# ------------------------
#
# SYNOPSIS
# ========
#
# Online usage::
#
#  $ . ./pomme_profile.sh -d directory -i indir -o outdir -t tempdir
#
# In ${HOME}/.profile, add the following line::
#
#  . pomme_profile.sh -d directory  -i indir -o outdir -t tempdir
#
# DESCRIPTION
# ===========
#
# .. option:: -d  <directory>
# .. option:: -i  <indir>
# .. option:: -o  <outdir>
# .. option:: -t  <tempdir>
#
# define POMME environment
#
# ${POMME} is the base directory of tools.
#
# ${POMME_LOG} is the directory where log files will be written.
#
# ${POMME_ID} is the directory where input files must be.
#
# ${POMME_OD} is the directory where output files will be written.
#
# PATH is completed with ${POMME}.
#
# SEE ALSO
# ========
#
# for IDL/GDL environment :
#
# :program:`pomme_startup.pro`
#
# EXAMPLES
# ========
#
# For fplod, on aedon.locean-ipsl.upmc.fr::
#
#  $ cd /usr/home/fplod/incas/pomme/pomme_ws/
#  $ . ./src/pomme_profile.sh \
#    -d $(pwd) \
#    -i /usr/temp/${LOGNAME}/pomme_d/ \
#    -o /usr/temp/${LOGNAME}/pomme_d/ \
#    -t /usr/temp/${LOGNAME}/log/
#
# For fplod on zeus.locean-ipsl.umpc.fr::
#
#  $ cd ${HOME}/incas/pomme/pomme_ws/
#  $ . ./src/pomme_profile.sh \
#    -d $(pwd) \
#    -i /usr/temp/${LOGNAME}/pomme_d/ \
#    -o /usr/temp/${LOGNAME}/pomme_d/ \
#    -t /usr/temp/${LOGNAME}/log/
#
# For pinsard on camelot.ipsl.polytechnique.fr or merlin15-c.climserv::
#
#  $ cd ${HOME}/pomme/
#  $ . ./src/pomme_profile.sh \
#   -d $(pwd) \
#   -i /homedata/${LOGNAME}/pomme_d/ \
#   -o /homedata/${LOGNAME}/pomme_d/ \
#   -t /homedata/${LOGNAME}/log/
#
# TODO
# ====
#
# ++ option bavarde
#
# ++ machine dependant
#
# ++ besoin de posix
#
# ++ pas de MANPATH defini par dfaut sur zeus et cerbere
#
# define IDL_STARTUP
#
# EVOLUTIONS
# ==========
#
# - fplod 20101118T171653Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * creation
#
#-
system=$(uname)
case "${system}" in
   AIX|IRIX64)
      echo " www : no specific posix checking"
   ;;
   *)
      set -o posix
   ;;
esac
unset system
#
LANG=C
#
# as this script might be launch in .profile, command is forced.
command=pomme_profile.sh
#
usage=" Usage : ${command} -d directory -i indir -o outdir -t tempdir"
#
set +u
while [ ! -z "${1}" ]
do
   case ${1} in
      -d)
         # directory for application choosen by user (see svn checkout command used)
         directory=${2}
         shift
      ;;
      -i)
         # directory for inputs choosen by user
         indir=${2}
         shift
      ;;
      -o)
         # directory for outputs choosen by user
         outdir=${2}
         shift
      ;;
      -t)
         # directory for temporary outputs choosen by user
         tempdir=${2}
         shift
      ;;
      *)
         # other choice
         echo "eee : unknown option ${1}"
         echo "${usage}"
         # nb : no exit because this file should be launched by login process
      ;;
   esac
   # next flag
   shift
done
unset usage
#
# check for ${directory}
if [ ! -d ${directory} ]
then
   echo " eee : ${directory} not found"
   # nb : no exit because this file should be launched by login process
fi
#
# check for permission on directory
if [ ! -x ${directory} ]
then
   echo " eee : ${directory} not reachable"
   # nb : no exit because this file should be launched by login process
fi
#
POMME=${directory}
export POMME
unset drectory
#
# add POMME tools to PATH
# if not already done
suppath=$(echo ${POMME}/src | tr -s "/")
echo ${PATH} | grep -q "${suppath}:"
test_path=${?}
if [ ${test_path} -ne 0 ]
then
   PATH=${suppath}:${PATH}
   export PATH
else
   # option bavarde oui/non pas encore implante ++
   echo "${command} : iii : ${suppath} already in \${PATH}"
fi
unset test_path
#
# add POMME manuals to MANPATH
# if not already done
suppath=$(echo ${POMME}/doc/man | tr -s "/")
echo ${MANPATH} | grep -q "${suppath}:"
test_manpath=${?}
if [ ${test_manpath} -ne 0 ]
then
   MANPATH=${suppath}:${MANPATH}
   export MANPATH
else
   # option bavarde oui/non pas encore implante ++
   echo "${command} : iii : ${suppath} already in \${MANPATH}"
fi
unset test_manpath
unset suppath
#
POMME_LOG=${tempdir}
export POMME_LOG
unset tempdir
if [ ! -d ${POMME_LOG} ]
then
   mkdir -p ${POMME_LOG}
   status=${?}
   if [ ${status} -ne 0 ]
   then
      echo "${command} : eee : can not create \${POMME_LOG}"
      # nb : no exit because this file should be launched by login process
   else
      echo "${command} : iii : creation of \${POMME_LOG}"
   fi
   unset status
fi
# check for permission on POMME_LOG
if [ ! -x ${POMME_LOG} ]
then
   echo " eee : ${POMME_LOG} not reachable"
   # nb : no exit because this file should be launched by login process
fi
#
# check for permission on POMME_LOG
if [ ! -w ${POMME_LOG} ]
then
   echo " eee : ${POMME_LOG} not writable"
   # nb : no exit because this file shouldreachable be launched by login process
fi
#
EDITOR=vi
export EDITOR
#
# io directories
POMME_ID=${indir}
export POMME_ID
unset indir
if [ ! -d ${POMME_ID} ]
then
   mkdir -p ${POMME_ID}
   echo "${command} : iii : creation of \${POMME_ID}"
fi
# check for permission on POMME_ID
if [ ! -x ${POMME_ID} ]
then
   echo " eee : ${POMME_ID} not reachable"
   # nb : no exit because this file should be launched by login process
fi
#
POMME_OD=${outdir}
export POMME_OD
unset outdir
if [ ! -d ${POMME_OD} ]
then
    mkdir -p ${POMME_OD}
    echo "${command} : iii : creation of \${POMME_OD}"
fi
# check for permission on POMME_OD
if [ ! -x ${POMME_OD} ]
then
   echo " eee : ${POMME_OD} not reachable"
   # nb : no exit because this file should be launched by login process
fi
if [ ! -w ${POMME_OD} ]
then
   echo " eee : ${POMME_OD} not writable"
   # nb : no exit because this file should be launched by login process
fi
#
# end
unset command
# nb : no exit because this file should be launched by login process
